package org.apache.commons.lang3.function;

import java.lang.Throwable;
import java.util.Objects;

@FunctionalInterface
/* loaded from: org_apache_commons_lang3_function.jar:org/apache/commons/lang3/function/FailableConsumer.class */
public interface FailableConsumer<T, E extends Throwable> {
    public static final FailableConsumer NOP = t -> {
    };

    void accept(T t) throws Throwable;

    static <T, E extends Throwable> FailableConsumer<T, E> nop() {
        return NOP;
    }

    default FailableConsumer<T, E> andThen(FailableConsumer<? super T, E> after) {
        Objects.requireNonNull(after);
        return obj -> {
            accept(obj);
            after.accept(obj);
        };
    }
}
